==> vsensebox-0.2.0.tar.gz: vsensebox-0.2.0/README.md <==
# 👁️📦 [**VSenseBox**](https://github.com/numediart/vsensebox)

<div align="center">

[![Documentation](https://github.com/numediart/vsensebox/actions/workflows/documentation.yaml/badge.svg)](https://github.com/numediart/vsensebox/actions/workflows/documentation.yaml) [![Publish on PyPI](https://github.com/numediart/vsensebox/actions/workflows/publish_pypi.yaml/badge.svg)](https://github.com/numediart/vsensebox/actions/workflows/publish_pypi.yaml) [![Test Build](https://github.com/numediart/vsensebox/actions/workflows/test_build.yaml/badge.svg)](https://github.com/numediart/vsensebox/actions/workflows/test_build.yaml)

[![Test Windows](https://github.com/numediart/vsensebox/actions/workflows/test_windows.yaml/badge.svg)](https://github.com/numediart/vsensebox/actions/workflows/test_windows.yaml) [![Test Linux](https://github.com/numediart/vsensebox/actions/workflows/test_linux.yaml/badge.svg)](https://github.com/numediart/vsensebox/actions/workflows/test_linux.yaml) [![Test macOS](https://github.com/numediart/vsensebox/actions/workflows/test_macos.yaml/badge.svg)](https://github.com/numediart/vsensebox/actions/workflows/test_macos.yaml)

<img src="https://raw.githubusercontent.com/rathaROG/screenshot/master/VSenseBox/vsensebox.jpg"><br />

**[📗 Documentation](https://numediart.github.io/vsensebox/) | [🚀 Getting started](https://numediart.github.io/vsensebox/getstarted.html) | [💡 Examples](https://numediart.github.io/vsensebox/examples.html)**

</div>

***VSenseBox*** is a small all-in-one Python toolbox filled with many vision/visual sensing modules such as object detectors and object trackers, etc. These modules are well integrated together and can be easily selected and configurated with minimal coding.

* Integrate with popular object detectors including YOLO v3, v4, v5, v8, v9, and more.
* Integrate with bbox trackers including Centroid, SORT, DeepSORT, and more TBA.
* Support Python 3.9-3.12 on Windows, Linux, and macOS.
* Support YAML config file for each individual module.
* Integrate with PyQt GUI for easy config.

==> vsensebox-0.4.0.tar.gz: vsensebox-0.4.0/README.md <==
# 👁️📦 [**VSenseBox**](https://github.com/numediart/vsensebox)

<div align="center">

[![Documentation](https://github.com/numediart/vsensebox/actions/workflows/documentation.yaml/badge.svg)](https://github.com/numediart/vsensebox/actions/workflows/documentation.yaml) [![Publish on PyPI](https://github.com/numediart/vsensebox/actions/workflows/publish_pypi.yaml/badge.svg)](https://github.com/numediart/vsensebox/actions/workflows/publish_pypi.yaml) [![Test Build](https://github.com/numediart/vsensebox/actions/workflows/test_build.yaml/badge.svg)](https://github.com/numediart/vsensebox/actions/workflows/test_build.yaml)

[![Test Windows](https://github.com/numediart/vsensebox/actions/workflows/test_windows.yaml/badge.svg)](https://github.com/numediart/vsensebox/actions/workflows/test_windows.yaml) [![Test Linux](https://github.com/numediart/vsensebox/actions/workflows/test_linux.yaml/badge.svg)](https://github.com/numediart/vsensebox/actions/workflows/test_linux.yaml) [![Test macOS](https://github.com/numediart/vsensebox/actions/workflows/test_macos.yaml/badge.svg)](https://github.com/numediart/vsensebox/actions/workflows/test_macos.yaml)

<img src="https://raw.githubusercontent.com/rathaROG/screenshot/refs/heads/master/VSenseBox/vsensebox.jpg"><br />

**[📗 Documentation](https://numediart.github.io/vsensebox/) | [🚀 Getting started](https://numediart.github.io/vsensebox/getstarted.html) | [💡 Examples](https://numediart.github.io/vsensebox/examples.html)**

</div>

***VSenseBox*** is a small all-in-one Python toolbox filled with many vision/visual sensing modules such as object detectors and object trackers, etc. These modules are well integrated together and can be easily selected and configurated with minimal coding.

* Integrate with popular object detectors including YOLO v3, v4, v5, v8, v9, v10, v11 and more.
* Integrate with bbox trackers including Centroid, SORT, DeepSORT, and more TBA.
* Support Python 3.9-3.12 on Windows, Linux, and macOS.
* Support YAML config file for each individual module.
* Integrate with PyQt GUI for easy config.
